<?php
/**
 * Plugin Name: COUB Custom
 * Version: 1.0.0
 *
 * A basic plugin that uses local proxy file to retrieve content from coub.
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

class COUB_Custom {

	/**
	 * Xprofile field ids , where you want it to be applied.
	 *
	 * @var array
	 */
	private $field_ids = array(
		87,
	);

	/**
	 * Boot this class.
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup hooks.
	 */
	private function setup() {
		add_filter( 'bp_get_the_profile_field_value', array( $this, 'fetch_profile_video' ), 9, 3 );
		// Register shortcode.
		add_shortcode( 'coub_embed', array( $this, 'shortcode' ) );
	}

	/**
	 * Show COUB videos from profile field.
	 *
	 * @param string $value field value.
	 * @param string $type field type.
	 * @param int    $id field id.
	 *
	 * @return string
	 */
	public function fetch_profile_video( $value, $type, $id ) {
		$value = trim( $value );

		if ( ! in_array( $id, $this->field_ids ) || empty( $value ) ) {
			return $value;
		}

		return do_shortcode( "[coub_embed]{$value}[/coub_embed]" );
	}

	/**
	 * Shortcode.
	 *
	 * @param array  $atts atts.
	 * @param string $coub_url embed url.
	 *
	 * @return string
	 */
	public function shortcode( $atts = array(), $coub_url = '' ) {

		if ( empty( $coub_url ) ) {
			return '';
		}

		$default_args = $this->get_default_args();

		$args = shortcode_atts(
			$default_args,
			$atts
		);

		$args['url'] = $coub_url;


		$proxy_url = plugin_dir_url( __FILE__ ) . 'proxy.php';

		$url = esc_url( add_query_arg( $args, $proxy_url ) );

		return "<iframe src='{$url}' allowfullscreen='true' frameborder='0' width='{$args['width']}' height='{$args['height']}'></iframe>";
	}

	/**
	 * Get default args.
	 *
	 * @return array
	 */
	private function get_default_args() {
		return array(
			'width'         => 450,
			'height'        => 360,
			// Yes, we are using 'true/false strings and not booleans as th service expects strings.
			'hideTopBar'    => 'true',
			'noSiteButtons' => 'true',
			'noHDControl'   => 'true',
			'muted'         => 'false',
			'autostart'     => 'false',
			'originalSize'  => 'true',
			'startWithHD'   => 'true',
		);
	}
}

// Boot the class.
COUB_Custom::boot();
